==> TPP_2.2.6.tar.gz: TPP/R/hdacTR_smallExample.R <==
#' @title Example subset of a Panobinostat TPP-TR dataset and the
#'   corresponding configuration table to start the analysis.
#' @name hdacTR_smallExample
#' @docType data
#' @description Example dataset obtained by TPP-TR experiments for analysis by 
#' the TPP-package. It contains all necessary arguments to start the analysis
#' (config table and list of data frames).
NULL
#' 
#' @rdname hdacTR_data
#' @name hdacTR_data
#' @title TPP-TR example dataset.
#' @description Example subset of a dataset obtained by TPP-TR experiments to 
#'   investigate possible targets for HDAC inhibitor Panobinostat.
#' @details \code{hdacTR_data} is a list of data frames that contain
#'   measurements for HDACs as well as a random selection of 500 further
#'   proteins.
#'   
#'   You can use this dataset to explore the \code{\link{TPP}} package 
#'   functionalities without invoking the whole time consuming analysis on the 
#'   whole dataset.
#'   
#'   The originial dataset is located in the folder 
#'   \code{'example_data/TR_example_data'} in the package's installation
#'   directory. You can find it on your system by the \code{R} command
#'   \code{system.file('example_data', package = 'TPP')}.
NULL
#'
#'@rdname hdacTR_config
#'@name hdacTR_config
#'@title The configuration table to analyze \link{hdacTR_data}.
#'@description The configuration table to analyze \link{hdacTR_data}.
#'@details \code{hdacTR_config} is a data frame that specifies the experiment 
#'  name, isobaric labels, and the administered temperatures at each 
#'  label.
NULL

==> TPP_3.4.3.tar.gz: TPP/R/hdacTR_smallExample.R <==
#' @title Example subset of a Panobinostat TPP-TR dataset and the
#'   corresponding configuration table to start the analysis.
#' @name hdacTR_smallExample
#' @docType data
#' @description Example dataset obtained by TPP-TR experiments for analysis by 
#' the TPP-package. It contains all necessary arguments to start the analysis
#' (config table and list of data frames).
NULL
#' 
#' @rdname hdacTR_data
#' @name hdacTR_data
#' @title TPP-TR example dataset.
#' @description Example subset of a dataset obtained by TPP-TR experiments to 
#'   investigate possible targets for HDAC inhibitor Panobinostat.
#' @details \code{hdacTR_data} is a list of data frames that contain
#'   measurements for HDACs as well as a random selection of 500 further
#'   proteins.
#'   
#'   You can use this dataset to explore the \code{\link{TPP}} package 
#'   functionalities without invoking the whole time consuming analysis on the 
#'   whole dataset.
#'   
#'   The original dataset is located in the folder 
#'   \code{'example_data/TR_example_data'} in the package's installation
#'   directory. You can find it on your system by the \code{R} command
#'   \code{system.file('example_data', package = 'TPP')}.
NULL
#'
#'@rdname hdacTR_config
#'@name hdacTR_config
#'@title The configuration table to analyze \link{hdacTR_data}.
#'@description The configuration table to analyze \link{hdacTR_data}.
#'@details \code{hdacTR_config} is a data frame that specifies the experiment 
#'  name, isobaric labels, and the administered temperatures at each 
#'  label.
NULL
